/* ixf1002.h is the header file for the device depedent driver code*/
/*
** INTEL CORPORATION PROPRIETARY INFORMATION
** This software is supplied under the terms of a license agreement or
** nondisclosure agreement with Intel Corporation and may not be copied
** or disclosed except in accordance with the terms of that agreement.
** Copyright (C) 2000 Intel Corporation. All rights Reserved.
*/
#ifndef _IXF1002_H_
#define _IXF1002_H_

#define IXF1002_DEV_ID		0x05
#define IXF1002_DEV_REV		0x11 /*Current revision */
#define IXF1002_DEV_PORT_MAX	0x02

#define IXF1002_REG_BASE		0xf0808000
#define	IXF1002_CTRL_REG_PORT0		IXF1002_REG_BASE + 0
#define IXF1002_CTRL_REG_PORT1		IXF1002_REG_BASE + 0x1000
#define	IXF1002_STATCL_REG_PORT0	IXF1002_REG_BASE + 0x400
#define IXF1002_STATCL_REG_PORT1	IXF1002_REG_BASE + 0x1400
#define	IXF1002_STAT_REG_PORT0		IXF1002_REG_BASE + 0x800
#define IXF1002_STAT_REG_PORT1		IXF1002_REG_BASE + 0x1800

#define RD_REG(reg)		((reg) & 0xFF) 
#define WR_REG(reg, y)		((reg) = ((y) & 0xFF))
#define WOR_REG(reg, y)		((reg) |= ((y) & 0xFF))
#define WAND_REG(reg, y)	((reg) &= ((y) & 0xFF))

typedef struct {
                     unsigned int ctrl_reg_base;
		     unsigned int statcl_reg_base;
		     unsigned int stat_reg_base;
}IXF1002_BASE;

typedef struct {
    volatile unsigned int int_stt[2];
    volatile unsigned int int_en[2];  /* need initial value */
    volatile unsigned int port_ctr[2]; /* need initial value */
    volatile unsigned int id_rev[2];
    volatile unsigned int tx_rx_stt[2];
    volatile unsigned int tx_ov_stt[4];
    volatile unsigned int rx_ov_stt[4];
    volatile unsigned int pad1[14];
    volatile unsigned int tx_rx_err[2];
    volatile unsigned int ffo_tshd[2]; /* need initial value */
    volatile unsigned int port_mode[2]; /* need initial value */
    volatile unsigned int tx_rx_param[2]; /* need initial value */
    volatile unsigned int tx_tshd[2]; /* need initial value */
    volatile unsigned int pause_time[2]; /* need initial value */
    volatile unsigned int pkt_max_size[2]; /* need initial value */
    volatile unsigned int ipg_val[2]; /* need initial value */
    volatile unsigned int mac_add[6]; /* need initial value */
    volatile unsigned int vlan_tag[2]; /* need initial value */
    volatile unsigned int tx_ov_msk[4]; /* need initial value */
    volatile unsigned int rx_ov_msk[4]; /* need initial value */
    volatile unsigned int pad2[10];
    volatile unsigned int gmii_mng_acc[2]; /* need initial value */
    volatile unsigned int gmii_mng_dat[2]; /* need initial value */
    volatile unsigned int pad3[2];
    volatile unsigned int gmii_ctl[2]; /* need initial value */
    volatile unsigned int gmii_stt[2];
    volatile unsigned int pad4[4];
    volatile unsigned int an_adv[2]; /* need initial value */
    volatile unsigned int an_prt_abl[2]; /* need initial value */
    volatile unsigned int an_exp[2]; /* need initial value */
    volatile unsigned int an_np_tr[2]; /* need initial value */
    volatile unsigned int an_prt_np[2]; /* need initial value */
    volatile unsigned int pad5[12];
    volatile unsigned int gmii_ext_stt[2];
    volatile unsigned int gpcs_stt[2];
} IXF1002_CTRL_REG;

typedef struct {
     unsigned int tx_uni_ok_cnt[4];
     unsigned int tx_mlt_ok_cnt[4];
     unsigned int tx_brd_ok_cnt[4];
     unsigned int pad1[24];
     unsigned int tx_pkt_64_cnt[4];
     unsigned int tx_pkt_65_cnt[4];
     unsigned int tx_pkt_128_cnt[4];
     unsigned int tx_pkt_256_cnt[4];
     unsigned int tx_pkt_512_cnt[4];
     unsigned int tx_pkt_1024_cnt[4];
     unsigned int tx_pkt_1519_cnt[4];
     unsigned int tx_pause_cnt[4];
     unsigned int tx_err_cnt[4];
     unsigned int pad2[24];
     unsigned int tx_oct_ok_cnt[6];
     unsigned int pad3[2];
     unsigned int tx_oct_bad_cnt[6];
     unsigned int pad4[2];
     unsigned int rx_oct_ok_cnt[6];
     unsigned int pad5[2];
     unsigned int rx_oct_bad_cnt[6];
     unsigned int pad6[6];
     unsigned int rx_ovf_cnt[4];
     unsigned int rx_short_ok_cnt[4];
     unsigned int rx_short_crc_cnt[4];
     unsigned int rx_uni_ok_cnt[4];
     unsigned int rx_mlt_ok_cnt[4];
     unsigned int rx_brd_ok_cnt[4];
     unsigned int rx_norm_crc_cnt[4];
     unsigned int pad7[4];
     unsigned int rx_long_ok_cnt[4];
     unsigned int rx_long_crc_cnt[4];
     unsigned int rx_pkt_64_cnt[4];
     unsigned int rx_pkt_65_cnt[4];
     unsigned int rx_pkt_128_cnt[4];
     unsigned int rx_pkt_256_cnt[4];
     unsigned int rx_pkt_512_cnt[4];
     unsigned int rx_pkt_1024_cnt[4];
     unsigned int rx_pkt_1519_cnt[4];
     unsigned int rx_pause_cnt[4];
     unsigned int rx_fals_crs_cnt[4];
     unsigned int rx_gpcs_err_cnt[4];
} IXF1002_STAT_REG;

typedef	enum {
    IDLE,
    OPENNED,
    CLOSED,
    WORKING
}  PORT_STATES;
    	
			
typedef struct {
    unsigned int port_id;
    PORT_STATES  port_state;
    IXF1002_CTRL_REG	* ctrl_reg_ptr;
    IXF1002_STAT_REG	* stat_reg_ptr;
    IXF1002_STAT_REG	* statcl_reg_ptr;
}  GIGA_DEV_PORT;
 
#endif

